@@ -1,5 +1,5 @@
 /* sframe-opt.c - optimize FRE and FDE information in SFrame.
-   Copyright (C) 2022 Free Software Foundation, Inc.
+   Copyright (C) 2022-2026 Free Software Foundation, Inc.
 
    This file is part of GAS, the GNU Assembler.
 
@@ -21,6 +21,12 @@
 #include "as.h"
 #include "sframe.h"
 
+/* Much like everything in gen-sframe.c, the functions here aren't supposed
+   to ever be reached when SFrame isn't supported by a target.  */
+#ifndef support_sframe_p
+# define support_sframe_p() false
+#endif
+
 /* The function estimates the size of a rs_sframe variant frag based on
    the current values of the symbols.  It is called before the
    relaxation loop.  We set fr_subtype{0:2} to the expected length.  */
@@ -33,6 +39,8 @@ sframe_estimate_size_before_relax (fragS *frag)
   symbolS *widthS;
   int ret;
 
+  gas_assert (support_sframe_p ());
+
   /* We are dealing with two different kind of fragments here which need
      to be fixed up:
        - first, FRE start address in each FRE, and
@@ -53,9 +61,9 @@ sframe_estimate_size_before_relax (fragS *frag)
       widthS = exp->X_op_symbol;
       width = resolve_symbol_value (widthS);
 
-      if (width < SFRAME_FRE_TYPE_ADDR1_LIMIT)
+      if (width < (offsetT) SFRAME_FRE_TYPE_ADDR1_LIMIT)
 	ret = 1;
-      else if (width < SFRAME_FRE_TYPE_ADDR2_LIMIT)
+      else if (width < (offsetT) SFRAME_FRE_TYPE_ADDR2_LIMIT)
 	ret = 2;
       else
 	ret = 4;
@@ -75,6 +83,8 @@ sframe_relax_frag (fragS *frag)
 {
   int oldsize, newsize;
 
+  gas_assert (support_sframe_p ());
+
   oldsize = frag->fr_subtype & 7;
   if (oldsize == 7)
     oldsize = -1;
@@ -94,13 +104,16 @@ sframe_convert_frag (fragS *frag)
   offsetT value;
 
   offsetT rest_of_data;
-  uint8_t fde_type, fre_type;
+  uint8_t fde_pc_type, fre_type;
   uint8_t pauth_key;
+  bool signal_p;
 
   expressionS *exp;
   symbolS *dataS;
   symbolS *fsizeS, *diffS;
 
+  gas_assert (support_sframe_p ());
+
   /* We are dealing with two different kind of fragments here which need
      to be fixed up:
        - first, FRE start address in each FRE, and
@@ -116,23 +129,25 @@ sframe_convert_frag (fragS *frag)
 	 the fre_type.  */
       dataS = exp->X_add_symbol;
       rest_of_data = (symbol_get_value_expression(dataS))->X_add_number;
-      fde_type = SFRAME_V1_FUNC_FDE_TYPE (rest_of_data);
-      pauth_key = SFRAME_V1_FUNC_PAUTH_KEY (rest_of_data);
-      gas_assert (fde_type == SFRAME_FDE_TYPE_PCINC);
+      fde_pc_type = SFRAME_V3_FDE_PC_TYPE (rest_of_data);
+      pauth_key = SFRAME_V3_AARCH64_FDE_PAUTH_KEY (rest_of_data);
+      signal_p = SFRAME_V3_FDE_SIGNAL_P (rest_of_data);
+      gas_assert (fde_pc_type == SFRAME_V3_FDE_PCTYPE_INC);
 
       /* Calculate the applicable fre_type.  */
       fsizeS = exp->X_op_symbol;
       fsize = resolve_symbol_value (fsizeS);
-      if (fsize < SFRAME_FRE_TYPE_ADDR1_LIMIT)
+      if (fsize < (offsetT) SFRAME_FRE_TYPE_ADDR1_LIMIT)
 	fre_type = SFRAME_FRE_TYPE_ADDR1;
-      else if (fsize < SFRAME_FRE_TYPE_ADDR2_LIMIT)
+      else if (fsize < (offsetT) SFRAME_FRE_TYPE_ADDR2_LIMIT)
 	fre_type = SFRAME_FRE_TYPE_ADDR2;
       else
 	fre_type = SFRAME_FRE_TYPE_ADDR4;
 
       /* Create the new function info.  */
-      value = SFRAME_V1_FUNC_INFO (fde_type, fre_type);
-      value = SFRAME_V1_FUNC_INFO_UPDATE_PAUTH_KEY (pauth_key, value);
+      value = SFRAME_V3_FDE_FUNC_INFO (fde_pc_type, fre_type);
+      value = SFRAME_V3_FDE_UPDATE_PAUTH_KEY (pauth_key, value);
+      value = SFRAME_V3_FDE_UPDATE_SIGNAL_P (signal_p, value);
 
       frag->fr_literal[frag->fr_fix] = value;
     }
@@ -150,11 +165,11 @@ sframe_convert_frag (fragS *frag)
       switch (frag->fr_subtype & 7)
 	{
 	case 1:
-	  gas_assert (fsize < SFRAME_FRE_TYPE_ADDR1_LIMIT);
+	  gas_assert (fsize < (offsetT) SFRAME_FRE_TYPE_ADDR1_LIMIT);
 	  frag->fr_literal[frag->fr_fix] = diff;
 	  break;
 	case 2:
-	  gas_assert (fsize < SFRAME_FRE_TYPE_ADDR2_LIMIT);
+	  gas_assert (fsize < (offsetT) SFRAME_FRE_TYPE_ADDR2_LIMIT);
 	  md_number_to_chars (frag->fr_literal + frag->fr_fix, diff, 2);
 	  break;
 	case 4:
